cgexplore.terms.TargetCosineAngle
=================================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetCosineAngle
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetCosineAngle.human_readable
      ~TargetCosineAngle.vector
      ~TargetCosineAngle.vector_key
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetCosineAngle.type1
      ~TargetCosineAngle.type2
      ~TargetCosineAngle.type3
      ~TargetCosineAngle.element1
      ~TargetCosineAngle.element2
      ~TargetCosineAngle.element3
      ~TargetCosineAngle.n
      ~TargetCosineAngle.b
      ~TargetCosineAngle.angle_k
   
   